@@ -35,9 +35,9 @@
 
 #include <KAlarmCal/AlarmText>
 
-#include <AkonadiCore/Item>
-#include <KCalendarCore/MemoryCalendar>
+#include <Akonadi/Item>
 #include <KCalUtils/ICalDrag>
+#include <KCalendarCore/MemoryCalendar>
 using namespace KCalendarCore;
 using namespace KCalUtils;
 
@@ -55,7 +55,6 @@ using namespace KCalUtils;
 #include <KToggleAction>
 #include <KNotifyConfigWidget>
 #include <KToolBarPopupAction>
-#include <kxmlgui_version.h>
 
 #include <QAction>
 #include <QSplitter>
@@ -64,7 +63,6 @@ using namespace KCalUtils;
 #include <QDropEvent>
 #include <QResizeEvent>
 #include <QCloseEvent>
-#include <QDesktopWidget>
 #include <QMenu>
 #include <QMimeDatabase>
 #include <QInputDialog>
@@ -1255,11 +1253,7 @@ void MainWindow::slotToggleMenubar(bool dontShowWarning)
 */
 void MainWindow::slotConfigureKeys()
 {
-#if KXMLGUI_VERSION < QT_VERSION_CHECK(5,84,0)
-    KShortcutsDialog::configure(actionCollection(), KShortcutsEditor::LetterShortcutsAllowed, this);
-#else
     KShortcutsDialog::showDialog(actionCollection(),  KShortcutsEditor::LetterShortcutsAllowed, this);
-#endif
 }
 
 /******************************************************************************
