@@ -76,7 +76,7 @@ public:
         connect(qApp, &QGuiApplication::saveStateRequest, this, &MNSessionManager::saveState);
 #endif
     }
-    ~MNSessionManager() {} 
+    ~MNSessionManager() override {} 
 
     static void create()
     {
@@ -162,7 +162,7 @@ MessageNotification::MessageNotification(const KAEvent& event, const KAAlarm& al
     if (!(flags & NoInitView))
         MessageNotification::setUpDisplay();    // avoid calling virtual method from constructor
 
-    connect(this, QOverload<unsigned int>::of(&KNotification::activated), this, &MessageNotification::buttonActivated);
+    connect(this, qOverload<unsigned int>(&KNotification::activated), this, &MessageNotification::buttonActivated);
     connect(this, &KNotification::closed, this, &MessageNotification::slotClosed);
     connect(mHelper, &MessageDisplayHelper::textsChanged, this, &MessageNotification::textsChanged);
     connect(mHelper, &MessageDisplayHelper::commandExited, this, &MessageNotification::commandCompleted);
@@ -185,7 +185,7 @@ MessageNotification::MessageNotification(const KAEvent& event, const DateTime& a
     setWidget(MainWindow::mainMainWindow());
     MessageNotification::setUpDisplay();    // avoid calling virtual method from constructor
 
-    connect(this, QOverload<unsigned int>::of(&KNotification::activated), this, &MessageNotification::buttonActivated);
+    connect(this, qOverload<unsigned int>(&KNotification::activated), this, &MessageNotification::buttonActivated);
     connect(this, &KNotification::closed, this, &MessageNotification::slotClosed);
     connect(mHelper, &MessageDisplayHelper::textsChanged, this, &MessageNotification::textsChanged);
 
@@ -205,7 +205,7 @@ MessageNotification::MessageNotification(const QString& eventId, MessageDisplayH
     MNSessionManager::create();
     setWidget(MainWindow::mainMainWindow());
 
-    connect(this, QOverload<unsigned int>::of(&KNotification::activated), this, &MessageNotification::buttonActivated);
+    connect(this, qOverload<unsigned int>(&KNotification::activated), this, &MessageNotification::buttonActivated);
     connect(this, &KNotification::closed, this, &MessageNotification::slotClosed);
     connect(mHelper, &MessageDisplayHelper::textsChanged, this, &MessageNotification::textsChanged);
     connect(mHelper, &MessageDisplayHelper::commandExited, this, &MessageNotification::commandCompleted);
