@@ -1,7 +1,7 @@
 /*
  *  templatedlg.cpp  -  dialog to create, edit and delete alarm templates
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2004-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2004-2021 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -100,13 +100,13 @@ TemplateDlg::TemplateDlg(QWidget* parent)
 
     topLayout->addWidget(new KSeparator(Qt::Horizontal, this));
 
-    auto* buttonBox = new QDialogButtonBox(this);
+    auto buttonBox = new QDialogButtonBox(this);
     buttonBox->addButton(QDialogButtonBox::Close);
     connect(buttonBox, &QDialogButtonBox::rejected,
             this, &QDialog::close);
     topLayout->addWidget(buttonBox);
 
-    KActionCollection* actions = new KActionCollection(this);
+    KActionCollection* actions = new KActionCollection(this);   //NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
     QAction* act = KStandardAction::selectAll(mListView, &QTreeView::selectAll, actions);
     topLevelWidget()->addAction(act);
     act = KStandardAction::deselect(mListView, &QAbstractItemView::clearSelection, actions);
@@ -153,7 +153,7 @@ void TemplateDlg::slotCopy()
 {
     KAEvent event = mListView->selectedEvent();
     if (event.isValid())
-        KAlarm::editNewTemplate(&event, mListView);
+        KAlarm::editNewTemplate(event, mListView);
 }
 
 /******************************************************************************
@@ -164,7 +164,7 @@ void TemplateDlg::slotEdit()
 {
     KAEvent event = mListView->selectedEvent();
     if (event.isValid())
-        KAlarm::editTemplate(&event, mListView);
+        KAlarm::editTemplate(event, mListView);
 }
 
 /******************************************************************************
